@@ -504,7 +504,7 @@ def wave(c1, d, X, U, el, gamma, Hs, Tz, Ts, Tp):
         SfTMA = (2 * (math.pi * f) ** 2 * d) * alphaTMA * 9.81 * np.exp(-1.25 * fpJ ** 4 / f ** 4) * gammaTMA ** (
             np.exp(-0.5 * (f - fpJ) ** 2 / (0.07 * (f <= fpJ) + 0.09 * (f > fpJ)) ** 2 / fpJ ** 2)) / (
                             2 * math.pi) ** 4 / f ** 5 * (f <= (9.81 / d) ** 0.5 / 2 / math.pi) + \
-                (1 - 0.5 * (2 - 2 * math.pi * f * (d / 9.81) ** 0.5) ** 2) * alphaTMA * 9.81 ** 2 * np.exp(
+                ((1 - 0.5 * (2 - 2 * math.pi * f * (d / 9.81) ** 0.5) ** 2) * (2 * math.pi * f * (d/9.81) ** 0.5 < 2) + 1 * (2 * math.pi * f * (d/9.81) ** 0.5 >= 2)) * alphaTMA * 9.81 ** 2 * np.exp(
             -1.25 * fpJ ** 4 / f ** 4) * gammaTMA ** (
                     np.exp(-0.5 * (f - fpJ) ** 2 / (0.07 * (f <= fpJ) + 0.09 * (f > fpJ)) ** 2 / fpJ ** 2)) / (
                             2 * math.pi) ** 4 / f ** 5 * (
@@ -714,8 +714,8 @@ def wave(c1, d, X, U, el, gamma, Hs, Tz, Ts, Tp):
     plt.rcParams['axes.unicode_minus'] = False
     todayis = dt.utcnow()
     d1 = todayis.strftime("%Y%m%d%H%M%S")
-    plt.savefig(f'pichistory/{d1}-wavespectra.png',dpi = 300)
-    plt.savefig(f'var/www/flaskapp/pichistory/{d1}-wavespectra.png',dpi = 300)
+    # plt.savefig(f'pichistory/{d1}-wavespectra.png',dpi = 300)
+    # plt.savefig(f'var/www/flaskapp/pichistory/{d1}-wavespectra.png',dpi = 300)
     img = io.BytesIO()
     plt.savefig(img, format='png')
     img.seek(0)
