@@ -2,7 +2,7 @@
 Date         : 2022-12-18 12:33:46
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2022-12-19 10:34:07
+LastEditTime : 2022-12-19 11:06:37
 LastEditors  : BDFD
 Description  : 
 FilePath     : \WES_Calculation\windspeed.py
@@ -715,26 +715,26 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
     # section7.extend(['---结果汇总：',str(round(wdu,1))+'-min时距U\u2081\u2080(m/s)---'])
 
     if dT==0:#20221211
-        section7.extend(['滨水工',str(round(Up1[10],3))])
+        section7 += (('滨水工',str(round(Up1[10],3))),)
     else:
-        section7.extend(['滨水工',str(round(Up1[10],3))+'(KEYPS)'+'    |    '+str(round(Up2[10],3))+'(B-D)'])
+        section7 += (('滨水工',str(round(Up1[10],3))+'(KEYPS)'+'    |    '+str(round(Up2[10],3))+'(B-D)'),)
 
     if ss1==None:
-        section7.extend(['JTS 145-2015',str(round(Ua1,3))])
+        section7 += (('JTS 145-2015',str(round(Ua1,3))),)
     else:
-        section7.extend(['JTS 145-2015','无有效方法'])
+        section7 += (('JTS 145-2015','无有效方法'),)
     
-    section7.extend(['SPM 1984',str(round(U102,3))])
+    section7 += (('SPM 1984',str(round(U102,3))),)
 
     if ss3==None:
-        section7.extend(['CEM',str(round(Ua3,3))])
+        section7 += (('CEM',str(round(Ua3,3))),)
     else:
-        section7.extend(['CEM','信息不足'])
+        section7 += (('CEM','信息不足'),)
 
     if ss6==None:
-        section7.extend(['API RP 2A-WSD',str(round(Ua6,3))])
+        section7 += (('API RP 2A-WSD',str(round(Ua6,3))),)
     else:
-        section7.extend(['API RP 2A-WSD','无有效方法'])
+        section7 += (('API RP 2A-WSD','无有效方法'),)
 
     ending = '---结果展示结束---'
 
